# Bowtie

[![Join the chat at https://gitter.im/bowtie-py/Lobby](https://badges.gitter.im/bowtie-py/Lobby.svg)](https://gitter.im/bowtie-py/Lobby?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)
[![Forum](https://img.shields.io/badge/-Google%20Group-blue.svg)](https://groups.google.com/forum/#!forum/bowtie-py)
[![Documentation Status](https://readthedocs.org/projects/bowtie-py/badge/?version=latest)](http://bowtie-py.readthedocs.io/en/latest/?badge=latest)
[![Build Status](https://travis-ci.org/jwkvam/bowtie.svg?branch=master)](https://travis-ci.org/jwkvam/bowtie)
[![PyPI version](https://badge.fury.io/py/bowtie.svg)](https://badge.fury.io/py/bowtie)
[![PyPI](https://img.shields.io/pypi/pyversions/bowtie.svg)](https://pypi.python.org/pypi/bowtie/)
[![codecov](https://codecov.io/gh/jwkvam/bowtie/branch/master/graph/badge.svg)](https://codecov.io/gh/jwkvam/bowtie)

![Demo](https://cloud.githubusercontent.com/assets/86304/20045988/69e5678a-a45a-11e6-853b-7f60a615c9da.gif)

## Introduction

Bowtie is a library for writing dashboards in Python.
No need to know web frameworks or JavaScript, focus on building functionality in Python.
Interactively explore your data in new ways!
Deploy and share with others!

## Demo

See a live [example](https://bowtie-demo.herokuapp.com/) generated from this [code](https://github.com/jwkvam/bowtie-demo/blob/master/example.py)!

## Gallery

For more examples, check out the [gallery](https://github.com/jwkvam/bowtie/wiki/Gallery). Feel free to add your own creations!

## Documentation

Available [here](http://bowtie-py.readthedocs.io/en/latest/).

## Install

```
pip install bowtie
```

## Requirements

Bowtie uses [Yarn](https://yarnpkg.com) to manage node packages.
Yarn can be installed through conda:
```
conda install -c conda-forge yarn
```

Otherwise follow [install instructions](https://yarnpkg.com/en/docs/install) for Yarn for your OS.

## The Goal

![@astrobiased @treycausey @vagabondjack the lack of a comprehensive production-grade Shiny-alike for Python is a Big Problem](https://cloud.githubusercontent.com/assets/86304/18606859/8ced55a6-7c70-11e6-8b5e-fba0ffcd78da.png)

## Contributing

You can help Bowtie in many ways including:
- Try it [out](http://bowtie-py.readthedocs.io/en/latest/quickstart.html) and report bugs or what was difficult.
- Help improve the [documentation](https://github.com/jwkvam/bowtie/tree/master/doc).
- Write new [widgets](http://bowtie-py.readthedocs.io/en/latest/newcomponents.html).
- Provide hosting for apps in the gallery.
- Say [thanks](https://saythanks.io/to/jwkvam)!
